@@ -243,7 +243,16 @@ def tick(
     is_flag=True,
     help="Wait for successful pipeline status before executing release.",
 )
-def release(ctx: click.Context, token: str, watch: bool, pipeline_check: bool) -> None:
+@click.option(
+    "-r",
+    "--rerelease",
+    default=False,
+    is_flag=True,
+    help="Allow the MR to have the same name as past closed MR.",
+)
+def release(
+    ctx: click.Context, token: str, watch: bool, pipeline_check: bool, rerelease: bool
+) -> None:
     r"""
     Create and display release merge request.
     """
@@ -259,7 +268,7 @@ def release(ctx: click.Context, token: str, watch: bool, pipeline_check: bool) -
 
         # will be skipped if pipeline is checked and failed
         while success:
-            done, _ = ctx.obj.release(token)
+            done, _ = ctx.obj.release(token, rerelease)
             if done or not watch:
                 break
             time.sleep(30)
