@@ -282,7 +282,7 @@ class GitlabSetter(ApiRequestCommunicator):
                 fg=self._col(job),
             )
 
-    def release(self) -> tp.Tuple[bool, bool]:
+    def release(self, rerelease: bool = False) -> tp.Tuple[bool, bool]:
         current_version, _ = self.ns.get_current_version_and_lines()
         mr_message = f"release {current_version}"
         coord = ["projects", self.project_id, "merge_requests"]
@@ -298,45 +298,36 @@ class GitlabSetter(ApiRequestCommunicator):
         n_success = len(show)
         error = 0
         success = 0
-        for mr in resp:  # pylint: disable=invalid-name
-            # check that there isnt an open mr to release already
-            if (
-                mr["source_branch"] == settings["source_branch"]
-                and mr["target_branch"] == settings["target_branch"]
-                and mr["title"] == mr_message
-                and mr["state"] == "opened"
-            ):
-                # if the pipeline fails, we set the merge again
-                if (
-                    not mr["merge_when_pipeline_succeeds"]
-                    and mr["state"] == "opened"
-                    and mr["merge_status"] == "can_be_merged"
-                ):
-                    resp = self.api_request(
-                        *coord,
-                        mr["iid"],
-                        "merge",
-                        mode="put",
-                        merge_when_pipeline_succeeds=True,
-                    )
-                resp = self.api_request("projects", self.project_id, "pipelines")
-                for pipeline in resp:
-                    self.pretty_pipeline(pipeline)
-                    if pipeline["ref"] in show:
-                        i = show.index(pipeline["ref"])
-                        show = show[i + 1 :]  # we dont want to see the old tag pipeline
-                        if pipeline["status"] != "success":
-                            error += 1
-                            self.display_pipeline(pipeline)
-                        else:
-                            success += 1
 
-                if success == n_success and not error:
-                    self._print("fully released, congrats :)", fg="green")
-                    return True, True
-                elif not error:
-                    self._print(f"release ongoing {success}/{n_success}", fg="yellow")
-                return False, False
+        for mr, needs_mwps in self._get_valid_mr(
+            resp, mr_message, rerelease, settings
+        ):  # pylint: disable=invalid-name
+            if needs_mwps:
+                resp = self.api_request(
+                    *coord,
+                    mr["iid"],
+                    "merge",
+                    mode="put",
+                    merge_when_pipeline_succeeds=True,
+                )
+            resp = self.api_request("projects", self.project_id, "pipelines")
+            for pipeline in resp:
+                self.pretty_pipeline(pipeline)
+                if pipeline["ref"] in show:
+                    i = show.index(pipeline["ref"])
+                    show = show[i + 1 :]  # we dont want to see the old tag pipeline
+                    if pipeline["status"] != "success":
+                        error += 1
+                        self.display_pipeline(pipeline)
+                    else:
+                        success += 1
+
+            if success == n_success and not error:
+                self._print("fully released, congrats :)", fg="green")
+                return True, True
+            elif not error:
+                self._print(f"release ongoing {success}/{n_success}", fg="yellow")
+            return False, False
 
         # create new mr
         mr = self.api_request(  # pylint: disable=invalid-name
@@ -367,3 +358,29 @@ class GitlabSetter(ApiRequestCommunicator):
             fg="yellow",
         )
         return False, False
+
+    def _get_valid_mr(
+        self,
+        mrs: tp.List[tp.Any],
+        mr_message: str,
+        rerelease: bool,
+        settings: tp.Dict[str, str],
+    ) -> tp.Iterator[tp.Any]:
+        for mr in mrs:
+            # check that there isnt an (open) mr to release already
+            if (
+                mr["source_branch"] == settings["source_branch"]
+                and mr["target_branch"] == settings["target_branch"]
+                and mr["title"] == mr_message
+            ):
+                if rerelease and mr["state"] != "opened":
+                    # ignore closed MR with same name on rerelease
+                    continue
+
+                # if the pipeline fails, we set the merge again
+                needs_mwps = (
+                    not mr["merge_when_pipeline_succeeds"]
+                    and mr["state"] == "opened"
+                    and mr["merge_status"] == "can_be_merged"
+                )
+                yield mr, needs_mwps
